==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity.md <==
# AwsTrustedAdvisorChecklistSecurity


```text
aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')
```



| Illustration | AwsTrustedAdvisorChecklistSecurity | AwsTrustedAdvisorChecklistSecurityCard | AwsTrustedAdvisorChecklistSecurityGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity.png) | ![illustration for AwsTrustedAdvisorChecklistSecurity](../../../aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity.Local.png) | ![illustration for AwsTrustedAdvisorChecklistSecurityCard](../../../aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurityCard.Local.png) | ![illustration for AwsTrustedAdvisorChecklistSecurityGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurityGroup.Local.png) |




## AwsTrustedAdvisorChecklistSecurity

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurity
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurity('AwsTrustedAdvisorChecklistSecurity', 'Aws Trusted Advisor Checklist Security', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurity
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurity('AwsTrustedAdvisorChecklistSecurity', 'Aws Trusted Advisor Checklist Security', 'an optional tech label')
@enduml
```

## AwsTrustedAdvisorChecklistSecurityCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurityCard
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurityCard('AwsTrustedAdvisorChecklistSecurityCard', 'Aws Trusted Advisor Checklist Security Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurityCard
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurityCard('AwsTrustedAdvisorChecklistSecurityCard', 'Aws Trusted Advisor Checklist Security Card', 'an optional description')
@enduml
```

## AwsTrustedAdvisorChecklistSecurityGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurityGroup
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurityGroup('AwsTrustedAdvisorChecklistSecurityGroup', 'Aws Trusted Advisor Checklist Security Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurityGroup
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurityGroup('AwsTrustedAdvisorChecklistSecurityGroup', 'Aws Trusted Advisor Checklist Security Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity.md <==
# AwsTrustedAdvisorChecklistSecurity


```text
aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')
```



| Illustration | AwsTrustedAdvisorChecklistSecurity | AwsTrustedAdvisorChecklistSecurityCard | AwsTrustedAdvisorChecklistSecurityGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity.png) | ![illustration for AwsTrustedAdvisorChecklistSecurity](../../../aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity.Local.png) | ![illustration for AwsTrustedAdvisorChecklistSecurityCard](../../../aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurityCard.Local.png) | ![illustration for AwsTrustedAdvisorChecklistSecurityGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurityGroup.Local.png) |




## AwsTrustedAdvisorChecklistSecurity

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurity
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurity('AwsTrustedAdvisorChecklistSecurity', 'Aws Trusted Advisor Checklist Security', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurity
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurity('AwsTrustedAdvisorChecklistSecurity', 'Aws Trusted Advisor Checklist Security', 'an optional tech label')
@enduml
```

## AwsTrustedAdvisorChecklistSecurityCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurityCard
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurityCard('AwsTrustedAdvisorChecklistSecurityCard', 'Aws Trusted Advisor Checklist Security Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurityCard
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurityCard('AwsTrustedAdvisorChecklistSecurityCard', 'Aws Trusted Advisor Checklist Security Card', 'an optional description')
@enduml
```

## AwsTrustedAdvisorChecklistSecurityGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurityGroup
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurityGroup('AwsTrustedAdvisorChecklistSecurityGroup', 'Aws Trusted Advisor Checklist Security Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTrustedAdvisorChecklistSecurityGroup
include('aws-20210730/Resource/ManagementGovernance/AwsTrustedAdvisorChecklistSecurity')

' renders the element
AwsTrustedAdvisorChecklistSecurityGroup('AwsTrustedAdvisorChecklistSecurityGroup', 'Aws Trusted Advisor Checklist Security Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
